==> 1.3.tar.gz: light-task-scheduler/job-core/src/main/java/com/lts/job/core/domain/Job.java <==
package com.lts.job.core.domain;


import com.lts.job.remoting.annotation.NotNull;

import java.util.HashMap;
import java.util.Map;

/**
 * @author Robert HG (254963746@qq.com) on 8/13/14.
 */
public class Job {

    protected String jobId;
    @NotNull
    protected String taskId;
    /**
     * 优先级 (数值越大 优先级越低)
     */
    protected Integer priority = 0;
    // 提交的节点
    @NotNull
    protected String nodeGroup;
    // 执行的节点
    @NotNull
    protected String taskTrackerNodeGroup;

    protected Map<String, String> extParams;
    // 是否要反馈给客户端
    protected boolean needFeedback = true;

    /**
     * 执行表达式 和 quartz 的一样
     * 如果这个为空，表示立即执行的
     */
    private String cronExpression;

    /**
     * 任务的最早出发时间
     * 如果设置了 cronExpression， 那么这个字段没用
     */
    private Long triggerTime;

    public Integer getPriority() {
        return priority;
    }

    public void setPriority(Integer priority) {
        this.priority = priority;
    }

    public String getTaskId() {
        return taskId;
    }

    public void setTaskId(String taskId) {
        this.taskId = taskId;
    }

    public String getNodeGroup() {
        return nodeGroup;
    }

    public void setNodeGroup(String nodeGroup) {
        this.nodeGroup = nodeGroup;
    }

    public String getTaskTrackerNodeGroup() {
        return taskTrackerNodeGroup;
    }

    public void setTaskTrackerNodeGroup(String taskTrackerNodeGroup) {
        this.taskTrackerNodeGroup = taskTrackerNodeGroup;
    }

    public boolean isNeedFeedback() {
        return needFeedback;
    }

    public void setNeedFeedback(boolean needFeedback) {
        this.needFeedback = needFeedback;
    }

    public String getJobId() {
        return jobId;
    }

    public void setJobId(String jobId) {
        this.jobId = jobId;
    }

    public Map<String, String> getExtParams() {
        return extParams;
    }

    public void setExtParams(Map<String, String> extParams) {
        this.extParams = extParams;
    }

    public String getParam(String key) {
        if (extParams == null) {
            return null;
        }
        return extParams.get(key);
    }

    public void setParam(String key, String value) {
        if (extParams == null) {
            extParams = new HashMap<String, String>();
        }
        extParams.put(key, value);
    }

    public String getCronExpression() {
        return cronExpression;
    }

    public void setCronExpression(String cronExpression) {
        this.cronExpression = cronExpression;
    }

    public boolean isSchedule(){
        return this.cronExpression != null && !"".equals(this.cronExpression.trim());
    }

    public Long getTriggerTime() {
        return triggerTime;
    }

    public void setTriggerTime(Long triggerTime) {
        this.triggerTime = triggerTime;
    }

    @Override
    public String toString() {
        return "Job{" +
                "jobId='" + jobId + '\'' +
                ", taskId='" + taskId + '\'' +
                ", priority=" + priority +
                ", nodeGroup='" + nodeGroup + '\'' +
                ", taskTrackerNodeGroup='" + taskTrackerNodeGroup + '\'' +
                ", extParams=" + extParams +
                ", needFeedback=" + needFeedback +
                ", cronExpression='" + cronExpression + '\'' +
                ", triggerTime=" + triggerTime +
                '}';
    }
}

==> 1.4.2.tar.gz: light-task-scheduler/job-core/src/main/java/com/lts/job/core/domain/Job.java <==
package com.lts.job.core.domain;


import com.lts.job.core.exception.JobSubmitException;
import com.lts.job.core.util.JSONUtils;
import com.lts.job.remoting.annotation.NotNull;

import java.util.HashMap;
import java.util.Map;

/**
 * @author Robert HG (254963746@qq.com) on 8/13/14.
 */
public class Job {

    protected String jobId;
    @NotNull
    protected String taskId;
    /**
     * 优先级 (数值越大 优先级越低)
     */
    protected Integer priority = 100;
    // 提交的节点 （可以手动指定）
    protected String submitNodeGroup;
    // 执行的节点
    @NotNull
    protected String taskTrackerNodeGroup;

    protected Map<String, String> extParams;
    // 是否要反馈给客户端
    protected boolean needFeedback = true;

    /**
     * 执行表达式 和 quartz 的一样
     * 如果这个为空，表示立即执行的
     */
    private String cronExpression;

    /**
     * 任务的最早出发时间
     * 如果设置了 cronExpression， 那么这个字段没用
     */
    private Long triggerTime;

    public Integer getPriority() {
        return priority;
    }

    public void setPriority(Integer priority) {
        this.priority = priority;
    }

    public String getTaskId() {
        return taskId;
    }

    public void setTaskId(String taskId) {
        this.taskId = taskId;
    }

    public String getSubmitNodeGroup() {
        return submitNodeGroup;
    }

    public void setSubmitNodeGroup(String submitNodeGroup) {
        this.submitNodeGroup = submitNodeGroup;
    }

    public String getTaskTrackerNodeGroup() {
        return taskTrackerNodeGroup;
    }

    public void setTaskTrackerNodeGroup(String taskTrackerNodeGroup) {
        this.taskTrackerNodeGroup = taskTrackerNodeGroup;
    }

    public boolean isNeedFeedback() {
        return needFeedback;
    }

    public void setNeedFeedback(boolean needFeedback) {
        this.needFeedback = needFeedback;
    }

    public String getJobId() {
        return jobId;
    }

    public void setJobId(String jobId) {
        this.jobId = jobId;
    }

    public Map<String, String> getExtParams() {
        return extParams;
    }

    public void setExtParams(Map<String, String> extParams) {
        this.extParams = extParams;
    }

    public String getParam(String key) {
        if (extParams == null) {
            return null;
        }
        return extParams.get(key);
    }

    public void setParam(String key, String value) {
        if (extParams == null) {
            extParams = new HashMap<String, String>();
        }
        extParams.put(key, value);
    }

    public String getCronExpression() {
        return cronExpression;
    }

    public void setCronExpression(String cronExpression) {
        this.cronExpression = cronExpression;
    }

    public boolean isSchedule(){
        return this.cronExpression != null && !"".equals(this.cronExpression.trim());
    }

    public Long getTriggerTime() {
        return triggerTime;
    }

    public void setTriggerTime(Long triggerTime) {
        this.triggerTime = triggerTime;
    }

    @Override
    public String toString() {
        return JSONUtils.toJSONString(this);
    }

    public void checkField() throws JobSubmitException {
        if(taskId == null){
            throw new JobSubmitException("taskId不能为空!");
        }
        if(taskTrackerNodeGroup == null){
            throw new JobSubmitException("taskTrackerNodeGroup不能为空!");
        }
    }
}
